@@ -86,7 +86,7 @@
 #define KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWINDOWSYSTEM_NO_DEPRECATED
-#  define KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54200
+#  define KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54300
 #endif
 #ifdef KWINDOWSYSTEM_NO_DEPRECATED_WARNINGS
 #  define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0x54200
+#    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0x54300
 #  endif
 #endif
 
@@ -133,6 +133,12 @@
 #else
 #  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_62(text)
 #endif
+
+#if KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE >= 0x54300
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_67(text) KWINDOWSYSTEM_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_67(text)
+#endif
 #define KWINDOWSYSTEM_DEPRECATED_VERSION_5(minor, text)      KWINDOWSYSTEM_DEPRECATED_VERSION_5_##minor(text)
 #define KWINDOWSYSTEM_DEPRECATED_VERSION(major, minor, text) KWINDOWSYSTEM_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 
